/****************************************************************************
** Meta object code from reading C++ file 'ProcessSortFilterModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-systemmonitor-6.7.2/src/table/ProcessSortFilterModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProcessSortFilterModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22ProcessSortFilterModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ProcessSortFilterModel::qt_create_metaobjectdata<qt_meta_tag_ZN22ProcessSortFilterModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProcessSortFilterModel",
        "QML.Element",
        "auto",
        "filterStringChanged",
        "",
        "viewModeChanged",
        "hiddenAttributesChanged",
        "filterPidsChanged",
        "columnMappingChanged",
        "sorted",
        "sort",
        "column",
        "Qt::SortOrder",
        "order",
        "filterString",
        "viewMode",
        "ViewMode",
        "hiddenAttributes",
        "filterPids",
        "QVariantList",
        "columnMapping",
        "QVariantMap",
        "sortColumn",
        "sortOrder",
        "ViewOwn",
        "ViewUser",
        "ViewSystem",
        "ViewAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterStringChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hiddenAttributesChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterPidsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnMappingChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sorted'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'sort'
        QtMocHelpers::MethodData<void(int, Qt::SortOrder)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterString'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'viewMode'
        QtMocHelpers::PropertyData<enum ViewMode>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'hiddenAttributes'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'filterPids'
        QtMocHelpers::PropertyData<QVariantList>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'columnMapping'
        QtMocHelpers::PropertyData<QVariantMap>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'sortColumn'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'sortOrder'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ViewMode'
        QtMocHelpers::EnumData<enum ViewMode>(16, 16, QMC::EnumFlags{}).add({
            {   24, ViewMode::ViewOwn },
            {   25, ViewMode::ViewUser },
            {   26, ViewMode::ViewSystem },
            {   27, ViewMode::ViewAll },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProcessSortFilterModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProcessSortFilterModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ProcessSortFilterModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ProcessSortFilterModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22ProcessSortFilterModelE_t>.metaTypes,
    nullptr
} };

void ProcessSortFilterModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessSortFilterModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterStringChanged(); break;
        case 1: _t->viewModeChanged(); break;
        case 2: _t->hiddenAttributesChanged(); break;
        case 3: _t->filterPidsChanged(); break;
        case 4: _t->columnMappingChanged(); break;
        case 5: _t->sorted(); break;
        case 6: _t->sort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::filterStringChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::viewModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::hiddenAttributesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::filterPidsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::columnMappingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessSortFilterModel::*)()>(_a, &ProcessSortFilterModel::sorted, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filterString(); break;
        case 1: *reinterpret_cast<enum ViewMode*>(_v) = _t->viewMode(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->hiddenAttributes(); break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->filterPids(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->columnMapping(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->sortColumn(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->sortOrder(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterString(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setViewMode(*reinterpret_cast<enum ViewMode*>(_v)); break;
        case 2: _t->setHiddenAttributes(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setFilterPids(*reinterpret_cast<QVariantList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProcessSortFilterModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessSortFilterModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ProcessSortFilterModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int ProcessSortFilterModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ProcessSortFilterModel::filterStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProcessSortFilterModel::viewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ProcessSortFilterModel::hiddenAttributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ProcessSortFilterModel::filterPidsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ProcessSortFilterModel::columnMappingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ProcessSortFilterModel::sorted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
