/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<ColumnDisplayModel.h>)
#  include <ColumnDisplayModel.h>
#endif
#if __has_include(<ColumnSortFilterDisplayModel.h>)
#  include <ColumnSortFilterDisplayModel.h>
#endif
#if __has_include(<ComponentCacheProxyModel.h>)
#  include <ComponentCacheProxyModel.h>
#endif
#if __has_include(<ProcessSortFilterModel.h>)
#  include <ProcessSortFilterModel.h>
#endif
#if __has_include(<ReverseColumnsProxyModel.h>)
#  include <ReverseColumnsProxyModel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_table()
{
    qmlRegisterModule("org.kde.ksysguard.table", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ColumnDisplayModel>("org.kde.ksysguard.table", 254);
    qmlRegisterEnum<ColumnDisplayModel::Roles>("ColumnDisplayModel::Roles");
    qmlRegisterTypesAndRevisions<ColumnSortFilterDisplayModel>("org.kde.ksysguard.table", 254);
    qmlRegisterTypesAndRevisions<ComponentCacheAttached>("org.kde.ksysguard.table", 254);
    qmlRegisterTypesAndRevisions<ComponentCacheProxyModel>("org.kde.ksysguard.table", 254);
    qmlRegisterEnum<ComponentCacheProxyModel::Roles>("ComponentCacheProxyModel::Roles");
    qmlRegisterTypesAndRevisions<ProcessSortFilterModel>("org.kde.ksysguard.table", 254);
    qmlRegisterEnum<ProcessSortFilterModel::ViewMode>("ProcessSortFilterModel::ViewMode");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QIdentityProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<ReverseColumnsProxyModel>("org.kde.ksysguard.table", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.table", 254, 254);
}

static const QQmlModuleRegistration orgkdeksysguardtableRegistration("org.kde.ksysguard.table", qml_register_types_org_kde_ksysguard_table);
