/****************************************************************************
** Meta object code from reading C++ file 'PageDataObject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-systemmonitor-6.7.2/src/page/PageDataObject.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PageDataObject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PageDataObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto PageDataObject::qt_create_metaobjectdata<qt_meta_tag_ZN14PageDataObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PageDataObject",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Used for data storage",
        "loaded",
        "",
        "saved",
        "childrenChanged",
        "childInserted",
        "index",
        "childRemoved",
        "childMoved",
        "from",
        "to",
        "dirtyChanged",
        "insertChild",
        "PageDataObject*",
        "QVariantMap",
        "properties",
        "removeChild",
        "moveChild",
        "markDirty",
        "markClean",
        "children",
        "QQmlListProperty<PageDataObject>",
        "dirty",
        "fileName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childrenChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childInserted'
        QtMocHelpers::SignalData<void(int)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'childRemoved'
        QtMocHelpers::SignalData<void(int)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'childMoved'
        QtMocHelpers::SignalData<void(int, int)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'dirtyChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'insertChild'
        QtMocHelpers::MethodData<PageDataObject *(int, const QVariantMap &)>(18, 8, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Int, 12 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'removeChild'
        QtMocHelpers::MethodData<void(int)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'moveChild'
        QtMocHelpers::MethodData<void(int, int)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'markDirty'
        QtMocHelpers::MethodData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'markClean'
        QtMocHelpers::MethodData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'children'
        QtMocHelpers::PropertyData<QQmlListProperty<PageDataObject>>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'dirty'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<PageDataObject, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PageDataObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlPropertyMap::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageDataObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageDataObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PageDataObjectE_t>.metaTypes,
    nullptr
} };

void PageDataObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageDataObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        case 1: _t->saved(); break;
        case 2: _t->childrenChanged(); break;
        case 3: _t->childInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->childRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->childMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->dirtyChanged(); break;
        case 7: { PageDataObject* _r = _t->insertChild((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<PageDataObject**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->removeChild((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->moveChild((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->markDirty(); break;
        case 11: _t->markClean(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)()>(_a, &PageDataObject::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)()>(_a, &PageDataObject::saved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)()>(_a, &PageDataObject::childrenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)(int )>(_a, &PageDataObject::childInserted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)(int )>(_a, &PageDataObject::childRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)(int , int )>(_a, &PageDataObject::childMoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageDataObject::*)()>(_a, &PageDataObject::dirtyChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<PageDataObject>*>(_v) = _t->childrenProperty(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->dirty(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        default: break;
        }
    }
}

const QMetaObject *PageDataObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PageDataObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageDataObjectE_t>.strings))
        return static_cast<void*>(this);
    return QQmlPropertyMap::qt_metacast(_clname);
}

int PageDataObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlPropertyMap::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PageDataObject::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PageDataObject::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PageDataObject::childrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PageDataObject::childInserted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PageDataObject::childRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PageDataObject::childMoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void PageDataObject::dirtyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
