/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<FaceLoader.h>)
#  include <FaceLoader.h>
#endif
#if __has_include(<FacesModel.h>)
#  include <FacesModel.h>
#endif
#if __has_include(<PageController.h>)
#  include <PageController.h>
#endif
#if __has_include(<PageDataModel.h>)
#  include <PageDataModel.h>
#endif
#if __has_include(<PageDataObject.h>)
#  include <PageDataObject.h>
#endif
#if __has_include(<PageManager.h>)
#  include <PageManager.h>
#endif
#if __has_include(<PageSortModel.h>)
#  include <PageSortModel.h>
#endif
#if __has_include(<PagesModel.h>)
#  include <PagesModel.h>
#endif
#if __has_include(<WidgetExporter.h>)
#  include <WidgetExporter.h>
#endif
#if __has_include(<systemmonitor.h>)
#  include <systemmonitor.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_page()
{
    qmlRegisterModule("org.kde.ksysguard.page", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Configuration>("org.kde.ksysguard.page", 254);
    qmlRegisterTypesAndRevisions<FaceLoader>("org.kde.ksysguard.page", 254);
    qmlRegisterTypesAndRevisions<FacesModel>("org.kde.ksysguard.page", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<PageController>("org.kde.ksysguard.page", 254);
    qmlRegisterEnum<PageController::WriteableState>("PageController::WriteableState");
    qmlRegisterEnum<PageController::PageChanges>("PageController::PageChanges");
    qmlRegisterTypesAndRevisions<PageDataModel>("org.kde.ksysguard.page", 254);
    qmlRegisterEnum<PageDataModel::Roles>("PageDataModel::Roles");
    qmlRegisterTypesAndRevisions<PageDataObject>("org.kde.ksysguard.page", 254);
    qmlRegisterTypesAndRevisions<PageManager>("org.kde.ksysguard.page", 254);
    qmlRegisterTypesAndRevisions<PageSortModel>("org.kde.ksysguard.page", 254);
    qmlRegisterEnum<PageSortModel::Roles>("PageSortModel::Roles");
    qmlRegisterTypesAndRevisions<PagesModel>("org.kde.ksysguard.page", 254);
    qmlRegisterEnum<PagesModel::Roles>("PagesModel::Roles");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    qmlRegisterTypesAndRevisions<WidgetExporter>("org.kde.ksysguard.page", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.page", 254, 254);
}

static const QQmlModuleRegistration orgkdeksysguardpageRegistration("org.kde.ksysguard.page", qml_register_types_org_kde_ksysguard_page);
