/****************************************************************************
** Meta object code from reading C++ file 'systemmonitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../systemmonitor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systemmonitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto Configuration::qt_create_metaobjectdata<qt_meta_tag_ZN13ConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Configuration",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "sidebarCollapsedChanged",
        "",
        "sidebarWidthChanged",
        "pageOrderChanged",
        "hiddenPagesChanged",
        "startPageChanged",
        "lastVisitedPageChanged",
        "sidebarCollapsed",
        "isSidebarCollapsedImmutable",
        "sidebarWidth",
        "isSidebarWidthImmutable",
        "pageOrder",
        "isPageOrderImmutable",
        "hiddenPages",
        "isHiddenPagesImmutable",
        "startPage",
        "isStartPageImmutable",
        "lastVisitedPage",
        "isLastVisitedPageImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sidebarCollapsedChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidebarWidthChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageOrderChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hiddenPagesChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startPageChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastVisitedPageChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sidebarCollapsed'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSidebarCollapsedImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidebarWidth'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isSidebarWidthImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pageOrder'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isPageOrderImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hiddenPages'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isHiddenPagesImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'startPage'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isStartPageImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastVisitedPage'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isLastVisitedPageImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Configuration, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Configuration::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ConfigurationE_t>.metaTypes,
    nullptr
} };

void Configuration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Configuration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sidebarCollapsedChanged(); break;
        case 1: _t->sidebarWidthChanged(); break;
        case 2: _t->pageOrderChanged(); break;
        case 3: _t->hiddenPagesChanged(); break;
        case 4: _t->startPageChanged(); break;
        case 5: _t->lastVisitedPageChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::sidebarCollapsedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::sidebarWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::pageOrderChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::hiddenPagesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::startPageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::lastVisitedPageChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->sidebarCollapsed(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSidebarCollapsedImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->sidebarWidth(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isSidebarWidthImmutable(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->pageOrder(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPageOrderImmutable(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->hiddenPages(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isHiddenPagesImmutable(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->startPage(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isStartPageImmutable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->lastVisitedPage(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isLastVisitedPageImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSidebarCollapsed(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSidebarWidth(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setPageOrder(*reinterpret_cast<QStringList*>(_v)); break;
        case 6: _t->setHiddenPages(*reinterpret_cast<QStringList*>(_v)); break;
        case 8: _t->setStartPage(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setLastVisitedPage(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Configuration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Configuration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Configuration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Configuration::sidebarCollapsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Configuration::sidebarWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Configuration::pageOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Configuration::hiddenPagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Configuration::startPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Configuration::lastVisitedPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
