/****************************************************************************
** Meta object code from reading C++ file 'PageController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-systemmonitor-6.7.2/src/page/PageController.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PageController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PageControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto PageController::qt_create_metaobjectdata<qt_meta_tag_ZN14PageControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PageController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Used for data storage",
        "hiddenChanged",
        "",
        "outdatedChanged",
        "replacedOutdatedChanged",
        "writeableStateChanged",
        "loaded",
        "saved",
        "load",
        "save",
        "std::filesystem::path",
        "path",
        "QUrl",
        "upgrade",
        "PageChanges",
        "changes",
        "reset",
        "fileName",
        "data",
        "PageDataObject*",
        "hidden",
        "outdated",
        "replacedOutdated",
        "writeableState",
        "WriteableState",
        "Unknown",
        "NotWriteable",
        "Writeable",
        "LocalChanges",
        "KeepChanges",
        "DiscardChanges"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hiddenChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outdatedChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replacedOutdatedChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'writeableStateChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saved'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'load'
        QtMocHelpers::MethodData<bool()>(14, 8, QMC::AccessPublic, QMetaType::Bool),
        // Method 'save'
        QtMocHelpers::MethodData<bool(const std::filesystem::path &)>(15, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<bool()>(15, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'save'
        QtMocHelpers::MethodData<bool(const QUrl &)>(15, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 17 },
        }}),
        // Method 'upgrade'
        QtMocHelpers::MethodData<bool(enum PageChanges)>(19, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'reset'
        QtMocHelpers::MethodData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'data'
        QtMocHelpers::PropertyData<PageDataObject*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'hidden'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'outdated'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'replacedOutdated'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'writeableState'
        QtMocHelpers::PropertyData<enum WriteableState>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'WriteableState'
        QtMocHelpers::EnumData<enum WriteableState>(30, 30, QMC::EnumIsScoped).add({
            {   31, WriteableState::Unknown },
            {   32, WriteableState::NotWriteable },
            {   33, WriteableState::Writeable },
            {   34, WriteableState::LocalChanges },
        }),
        // enum 'PageChanges'
        QtMocHelpers::EnumData<enum PageChanges>(20, 20, QMC::EnumIsScoped).add({
            {   35, PageChanges::KeepChanges },
            {   36, PageChanges::DiscardChanges },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<PageController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PageController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PageControllerE_t>.metaTypes,
    nullptr
} };

void PageController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hiddenChanged(); break;
        case 1: _t->outdatedChanged(); break;
        case 2: _t->replacedOutdatedChanged(); break;
        case 3: _t->writeableStateChanged(); break;
        case 4: _t->loaded(); break;
        case 5: _t->saved(); break;
        case 6: { bool _r = _t->load();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->save((*reinterpret_cast<std::add_pointer_t<std::filesystem::path>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->save((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->upgrade((*reinterpret_cast<std::add_pointer_t<enum PageChanges>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::hiddenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::outdatedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::replacedOutdatedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::writeableStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::loaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageController::*)()>(_a, &PageController::saved, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PageDataObject* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 1: *reinterpret_cast<PageDataObject**>(_v) = _t->data(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isHidden(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isOutdated(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasReplacedOutdated(); break;
        case 5: *reinterpret_cast<enum WriteableState*>(_v) = _t->writeableState(); break;
        default: break;
        }
    }
}

const QMetaObject *PageController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PageController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PageControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PageController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void PageController::hiddenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PageController::outdatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PageController::replacedOutdatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PageController::writeableStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PageController::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PageController::saved()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
