/****************************************************************************
** Meta object code from reading C++ file 'PageManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-systemmonitor-6.7.2/src/page/PageManager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PageManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PageManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PageManager::qt_create_metaobjectdata<qt_meta_tag_ZN11PageManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PageManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "pagesChanged",
        "",
        "pageAdded",
        "PageController*",
        "page",
        "pageRemoved",
        "pageReset",
        "fileName",
        "addPage",
        "baseName",
        "QVariantMap",
        "properties",
        "importPage",
        "QUrl",
        "file",
        "removeLocalPageFiles",
        "ghnsEntryStatusChanged",
        "KNSCore::Entry",
        "entry",
        "saveAll",
        "pages",
        "QList<PageController*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pagesChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageAdded'
        QtMocHelpers::SignalData<void(PageController *)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'pageRemoved'
        QtMocHelpers::SignalData<void(PageController *)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'pageReset'
        QtMocHelpers::SignalData<void(PageController *)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'page'
        QtMocHelpers::MethodData<PageController *(const QString &)>(9, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'addPage'
        QtMocHelpers::MethodData<PageController *(const QString &, const QVariantMap &)>(13, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'addPage'
        QtMocHelpers::MethodData<PageController *(const QString &)>(13, 6, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'importPage'
        QtMocHelpers::MethodData<PageController *(const QUrl &)>(17, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Method 'removeLocalPageFiles'
        QtMocHelpers::MethodData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'ghnsEntryStatusChanged'
        QtMocHelpers::MethodData<PageController *(const KNSCore::Entry &)>(21, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'saveAll'
        QtMocHelpers::MethodData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pages'
        QtMocHelpers::PropertyData<QList<PageController*>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PageManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PageManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PageManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PageManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PageManagerE_t>.metaTypes,
    nullptr
} };

void PageManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pagesChanged(); break;
        case 1: _t->pageAdded((*reinterpret_cast<std::add_pointer_t<PageController*>>(_a[1]))); break;
        case 2: _t->pageRemoved((*reinterpret_cast<std::add_pointer_t<PageController*>>(_a[1]))); break;
        case 3: _t->pageReset((*reinterpret_cast<std::add_pointer_t<PageController*>>(_a[1]))); break;
        case 4: { PageController* _r = _t->page((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PageController**>(_a[0]) = std::move(_r); }  break;
        case 5: { PageController* _r = _t->addPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<PageController**>(_a[0]) = std::move(_r); }  break;
        case 6: { PageController* _r = _t->addPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PageController**>(_a[0]) = std::move(_r); }  break;
        case 7: { PageController* _r = _t->importPage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PageController**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->removeLocalPageFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { PageController* _r = _t->ghnsEntryStatusChanged((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PageController**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->saveAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PageController* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PageController* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PageController* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PageManager::*)()>(_a, &PageManager::pagesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageManager::*)(PageController * )>(_a, &PageManager::pageAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageManager::*)(PageController * )>(_a, &PageManager::pageRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageManager::*)(PageController * )>(_a, &PageManager::pageReset, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<PageController*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<PageController*>*>(_v) = _t->pages(); break;
        default: break;
        }
    }
}

const QMetaObject *PageManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PageManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PageManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PageManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PageManager::pagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PageManager::pageAdded(PageController * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PageManager::pageRemoved(PageController * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PageManager::pageReset(PageController * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
